( cd usr/bin ; rm -rf tclsh )
( cd usr/bin ; ln -sf tclsh8.4 tclsh )
( cd usr/lib ; rm -rf libtcl.a )
( cd usr/lib ; ln -sf libtcl8.4.a libtcl.a )
( cd usr/lib ; rm -rf libtcl.so )
( cd usr/lib ; ln -sf libtcl8.4.so libtcl.so )
( cd usr/lib ; rm -rf libtclstub.a )
( cd usr/lib ; ln -sf libtclstub8.4.a libtclstub.a )
( cd usr/man/man3 ; rm -rf Tcl_Access.3.gz )
( cd usr/man/man3 ; ln -sf Access.3.gz Tcl_Access.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AddErrorInfo.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_AddErrorInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AddObjErrorInfo.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_AddObjErrorInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AlertNotifier.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_AlertNotifier.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Alloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz Tcl_Alloc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AllocStatBuf.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_AllocStatBuf.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AllowExceptions.3.gz )
( cd usr/man/man3 ; ln -sf AllowExc.3.gz Tcl_AllowExceptions.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppInit.3.gz )
( cd usr/man/man3 ; ln -sf AppInit.3.gz Tcl_AppInit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendAllObjTypes.3.gz )
( cd usr/man/man3 ; ln -sf ObjectType.3.gz Tcl_AppendAllObjTypes.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendElement.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_AppendElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendObjToObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_AppendObjToObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_AppendResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendResultVA.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_AppendResultVA.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendStringsToObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_AppendStringsToObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendStringsToObjVA.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_AppendStringsToObjVA.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendToObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_AppendToObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AppendUnicodeToObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_AppendUnicodeToObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncCreate.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncCreate.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncDelete.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncDelete.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncInvoke.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncInvoke.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncMark.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncMark.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AsyncReady.3.gz )
( cd usr/man/man3 ; ln -sf Async.3.gz Tcl_AsyncReady.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AttemptAlloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz Tcl_AttemptAlloc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AttemptRealloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz Tcl_AttemptRealloc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_AttemptSetObjLength.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_AttemptSetObjLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_BackgroundError.3.gz )
( cd usr/man/man3 ; ln -sf BackgdErr.3.gz Tcl_BackgroundError.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Backslash.3.gz )
( cd usr/man/man3 ; ln -sf Backslash.3.gz Tcl_Backslash.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_BadChannelOption.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_BadChannelOption.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CallWhenDeleted.3.gz )
( cd usr/man/man3 ; ln -sf CallDel.3.gz Tcl_CallWhenDeleted.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CancelIdleCall.3.gz )
( cd usr/man/man3 ; ln -sf DoWhenIdle.3.gz Tcl_CancelIdleCall.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelBlockModeProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelBlockModeProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelBuffered.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelBuffered.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelClose2Proc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelClose2Proc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelCloseProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelCloseProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelFlushProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelFlushProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelGetHandleProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelGetHandleProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelGetOptionProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelGetOptionProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelHandlerProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelHandlerProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelInputProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelInputProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelName.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelOutputProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelOutputProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelSeekProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelSeekProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelSetOptionProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelSetOptionProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelVersion.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelVersion.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelWatchProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelWatchProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ChannelWideSeekProc.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ChannelWideSeekProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Chdir.3.gz )
( cd usr/man/man3 ; ln -sf GetCwd.3.gz Tcl_Chdir.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ClearChannelHandlers.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_ClearChannelHandlers.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Close.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Close.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CommandComplete.3.gz )
( cd usr/man/man3 ; ln -sf CmdCmplt.3.gz Tcl_CommandComplete.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CommandTraceInfo.3.gz )
( cd usr/man/man3 ; ln -sf TraceCmd.3.gz Tcl_CommandTraceInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Concat.3.gz )
( cd usr/man/man3 ; ln -sf Concat.3.gz Tcl_Concat.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConcatObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_ConcatObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConditionFinalize.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_ConditionFinalize.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConditionNotify.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_ConditionNotify.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConditionWait.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_ConditionWait.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConvertCountedElement.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_ConvertCountedElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConvertElement.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_ConvertElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ConvertToType.3.gz )
( cd usr/man/man3 ; ln -sf ObjectType.3.gz Tcl_ConvertToType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateAlias.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_CreateAlias.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateAliasObj.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_CreateAliasObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateChannel.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_CreateChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateChannelHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtChnlHdlr.3.gz Tcl_CreateChannelHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateCloseHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtCloseHdlr.3.gz Tcl_CreateCloseHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Eof.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Eof.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateCommand.3.gz )
( cd usr/man/man3 ; ln -sf CrtCommand.3.gz Tcl_CreateCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateEncoding.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_CreateEncoding.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateEventSource.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_CreateEventSource.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateExitHandler.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_CreateExitHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateFileHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtFileHdlr.3.gz Tcl_CreateFileHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_CreateHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateInterp.3.gz )
( cd usr/man/man3 ; ln -sf CrtInterp.3.gz Tcl_CreateInterp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateMathFunc.3.gz )
( cd usr/man/man3 ; ln -sf CrtMathFnc.3.gz Tcl_CreateMathFunc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateObjCommand.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_CreateObjCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateObjTrace.3.gz )
( cd usr/man/man3 ; ln -sf CrtTrace.3.gz Tcl_CreateObjTrace.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateSlave.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_CreateSlave.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateThread.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_CreateThread.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateThreadExitHandler.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_CreateThreadExitHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateTimerHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtTimerHdlr.3.gz Tcl_CreateTimerHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CreateTrace.3.gz )
( cd usr/man/man3 ; ln -sf CrtTrace.3.gz Tcl_CreateTrace.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_CutChannel.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_CutChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringAppend.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringAppend.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringAppendElement.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringAppendElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringEndSublist.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringEndSublist.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringFree.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringFree.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringGetResult.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringGetResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringInit.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringInit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringLength.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringResult.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringSetLength.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringSetLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringStartSublist.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringStartSublist.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringTrunc.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringTrunc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DStringValue.3.gz )
( cd usr/man/man3 ; ln -sf DString.3.gz Tcl_DStringValue.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DecrRefCount.3.gz )
( cd usr/man/man3 ; ln -sf Object.3.gz Tcl_DecrRefCount.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteAssocData.3.gz )
( cd usr/man/man3 ; ln -sf AssocData.3.gz Tcl_DeleteAssocData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteChannelHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtChnlHdlr.3.gz Tcl_DeleteChannelHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteCloseHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtCloseHdlr.3.gz Tcl_DeleteCloseHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteCommand.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_DeleteCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteCommandFromToken.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_DeleteCommandFromToken.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteEventSource.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_DeleteEventSource.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteEvents.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_DeleteEvents.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteExitHandler.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_DeleteExitHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteFileHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtFileHdlr.3.gz Tcl_DeleteFileHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_DeleteHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteHashTable.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_DeleteHashTable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteInterp.3.gz )
( cd usr/man/man3 ; ln -sf CrtInterp.3.gz Tcl_DeleteInterp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteThreadExitHandler.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_DeleteThreadExitHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteTimerHandler.3.gz )
( cd usr/man/man3 ; ln -sf CrtTimerHdlr.3.gz Tcl_DeleteTimerHandler.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DeleteTrace.3.gz )
( cd usr/man/man3 ; ln -sf CrtTrace.3.gz Tcl_DeleteTrace.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DetachChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_DetachChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DetachPids.3.gz )
( cd usr/man/man3 ; ln -sf DetachPids.3.gz Tcl_DetachPids.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DiscardResult.3.gz )
( cd usr/man/man3 ; ln -sf SaveResult.3.gz Tcl_DiscardResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DoOneEvent.3.gz )
( cd usr/man/man3 ; ln -sf DoOneEvent.3.gz Tcl_DoOneEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DoWhenIdle.3.gz )
( cd usr/man/man3 ; ln -sf DoWhenIdle.3.gz Tcl_DoWhenIdle.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DontCallWhenDeleted.3.gz )
( cd usr/man/man3 ; ln -sf CallDel.3.gz Tcl_DontCallWhenDeleted.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DumpActiveMemory.3.gz )
( cd usr/man/man3 ; ln -sf DumpActiveMemory.3.gz Tcl_DumpActiveMemory.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_DuplicateObj.3.gz )
( cd usr/man/man3 ; ln -sf Object.3.gz Tcl_DuplicateObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ErrnoId.3.gz )
( cd usr/man/man3 ; ln -sf SetErrno.3.gz Tcl_ErrnoId.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ErrnoMsg.3.gz )
( cd usr/man/man3 ; ln -sf SetErrno.3.gz Tcl_ErrnoMsg.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Eval.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_Eval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EvalEx.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_EvalEx.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EvalFile.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_EvalFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EvalObjEx.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_EvalObjEx.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EvalObjv.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_EvalObjv.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EvalTokens.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_EvalTokens.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EvalTokensStandard.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_EvalTokensStandard.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_EventuallyFree.3.gz )
( cd usr/man/man3 ; ln -sf Preserve.3.gz Tcl_EventuallyFree.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Exit.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_Exit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExitThread.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_ExitThread.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExposeCommand.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_ExposeCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprBoolean.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprBoolean.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprBooleanObj.3.gz )
( cd usr/man/man3 ; ln -sf ExprLongObj.3.gz Tcl_ExprBooleanObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprDouble.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprDouble.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprDoubleObj.3.gz )
( cd usr/man/man3 ; ln -sf ExprLongObj.3.gz Tcl_ExprDoubleObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprLong.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprLong.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprLongObj.3.gz )
( cd usr/man/man3 ; ln -sf ExprLongObj.3.gz Tcl_ExprLongObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprObj.3.gz )
( cd usr/man/man3 ; ln -sf ExprLongObj.3.gz Tcl_ExprObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExprString.3.gz )
( cd usr/man/man3 ; ln -sf ExprLong.3.gz Tcl_ExprString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExternalToUtf.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_ExternalToUtf.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ExternalToUtfDString.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_ExternalToUtfDString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSAccess.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSAccess.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSChdir.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSChdir.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSConvertToPathType.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSConvertToPathType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSCopyDirectory.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSCopyDirectory.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSCopyFile.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSCopyFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSCreateDirectory.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSCreateDirectory.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSData.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSDeleteFile.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSDeleteFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSEqualPaths.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSEqualPaths.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSEvalFile.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSEvalFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSFileAttrStrings.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSFileAttrStrings.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSFileAttrsGet.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSFileAttrsGet.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSFileAttrsSet.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSFileAttrsSet.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSFileSystemInfo.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSFileSystemInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetCwd.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetCwd.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetFileSystemForPath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetFileSystemForPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetInternalRep.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetInternalRep.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetNativePath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetNativePath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetNormalizedPath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetNormalizedPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetPathType.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetPathType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetTranslatedPath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetTranslatedPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSGetTranslatedStringPath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSGetTranslatedStringPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSJoinPath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSJoinPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSJoinToPath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSJoinToPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSLink.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSLink.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSListVolumes.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSListVolumes.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSLoadFile.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSLoadFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSLstat.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSLstat.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSMatchInDirectory.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSMatchInDirectory.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSMountsChanged.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSMountsChanged.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSNewNativePath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSNewNativePath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSOpenFileChannel.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSOpenFileChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSPathSeparator.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSPathSeparator.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSRegister.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSRegister.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSRemoveDirectory.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSRemoveDirectory.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSRenameFile.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSRenameFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSSplitPath.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSSplitPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSStat.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSStat.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSUnregister.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSUnregister.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FSUtime.3.gz )
( cd usr/man/man3 ; ln -sf FileSystem.3.gz Tcl_FSUtime.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Finalize.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_Finalize.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FinalizeNotifier.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_FinalizeNotifier.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FinalizeThread.3.gz )
( cd usr/man/man3 ; ln -sf Exit.3.gz Tcl_FinalizeThread.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FindExecutable.3.gz )
( cd usr/man/man3 ; ln -sf FindExec.3.gz Tcl_FindExecutable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FindHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_FindHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FirstHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_FirstHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Flush.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Flush.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Free.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz Tcl_Free.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FreeEncoding.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_FreeEncoding.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FreeParse.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_FreeParse.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_FreeResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_FreeResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetAlias.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetAlias.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetAliasObj.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetAliasObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetAssocData.3.gz )
( cd usr/man/man3 ; ln -sf AssocData.3.gz Tcl_GetAssocData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCwd.3.gz )
( cd usr/man/man3 ; ln -sf GetCwd.3.gz Tcl_GetCwd.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetBoolean.3.gz )
( cd usr/man/man3 ; ln -sf GetInt.3.gz Tcl_GetBoolean.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetBooleanFromObj.3.gz )
( cd usr/man/man3 ; ln -sf BoolObj.3.gz Tcl_GetBooleanFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetByteArrayFromObj.3.gz )
( cd usr/man/man3 ; ln -sf ByteArrObj.3.gz Tcl_GetByteArrayFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_GetChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelBufferSize.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelBufferSize.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelHandle.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelHandle.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelInstanceData.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelInstanceData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelMode.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelMode.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelName.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelNames.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_GetChannelNames.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelNamesEx.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_GetChannelNamesEx.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelOption.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_GetChannelOption.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelThread.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelThread.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetChannelType.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_GetChannelType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCharLength.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_GetCharLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCommandFromObj.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_GetCommandFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCommandFullName.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_GetCommandFullName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCommandInfo.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_GetCommandInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCommandInfoFromToken.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_GetCommandInfoFromToken.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCommandName.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_GetCommandName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetCurrentThread.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_GetCurrentThread.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetDefaultEncodingDir.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_GetDefaultEncodingDir.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetDouble.3.gz )
( cd usr/man/man3 ; ln -sf GetInt.3.gz Tcl_GetDouble.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetDoubleFromObj.3.gz )
( cd usr/man/man3 ; ln -sf DoubleObj.3.gz Tcl_GetDoubleFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetEncoding.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_GetEncoding.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetEncodingName.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_GetEncodingName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetEncodingNames.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_GetEncodingNames.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetErrno.3.gz )
( cd usr/man/man3 ; ln -sf SetErrno.3.gz Tcl_GetErrno.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetHashKey.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_GetHashKey.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetHashValue.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_GetHashValue.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetHostName.3.gz )
( cd usr/man/man3 ; ln -sf GetHostName.3.gz Tcl_GetHostName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetIndexFromObj.3.gz )
( cd usr/man/man3 ; ln -sf GetIndex.3.gz Tcl_GetIndexFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetIndexFromObjStruct.3.gz )
( cd usr/man/man3 ; ln -sf GetIndex.3.gz Tcl_GetIndexFromObjStruct.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetInt.3.gz )
( cd usr/man/man3 ; ln -sf GetInt.3.gz Tcl_GetInt.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetIntFromObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_GetIntFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetInterpPath.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetInterpPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetLongFromObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_GetLongFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetMaster.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetMaster.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetMathFuncInfo.3.gz )
( cd usr/man/man3 ; ln -sf CrtMathFnc.3.gz Tcl_GetMathFuncInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetNameOfExecutable.3.gz )
( cd usr/man/man3 ; ln -sf FindExec.3.gz Tcl_GetNameOfExecutable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetOSTypeFromObj.3.gz )
( cd usr/man/man3 ; ln -sf Macintosh.3.gz Tcl_GetOSTypeFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetObjResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_GetObjResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetObjType.3.gz )
( cd usr/man/man3 ; ln -sf ObjectType.3.gz Tcl_GetObjType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetOpenFile.3.gz )
( cd usr/man/man3 ; ln -sf GetOpnFl.3.gz Tcl_GetOpenFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetPathType.3.gz )
( cd usr/man/man3 ; ln -sf SplitPath.3.gz Tcl_GetPathType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetRange.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_GetRange.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetRegExpFromObj.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_GetRegExpFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetServiceMode.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_GetServiceMode.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetSlave.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_GetSlave.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetStackedChannel.3.gz )
( cd usr/man/man3 ; ln -sf ChnlStack.3.gz Tcl_GetStackedChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetStdChannel.3.gz )
( cd usr/man/man3 ; ln -sf GetStdChan.3.gz Tcl_GetStdChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetString.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_GetString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetStringFromObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_GetStringFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetStringResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_GetStringResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetThreadData.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_GetThreadData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetTime.3.gz )
( cd usr/man/man3 ; ln -sf GetTime.3.gz Tcl_GetTime.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetTopChannel.3.gz )
( cd usr/man/man3 ; ln -sf ChnlStack.3.gz Tcl_GetTopChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetUniChar.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_GetUniChar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetUnicode.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_GetUnicode.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetUnicodeFromObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_GetUnicodeFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetVar.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_GetVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_GetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetVar2Ex.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_GetVar2Ex.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetVersion.3.gz )
( cd usr/man/man3 ; ln -sf GetVersion.3.gz Tcl_GetVersion.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetWideIntFromObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_GetWideIntFromObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Gets.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Gets.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GetsObj.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_GetsObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GlobalEval.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_GlobalEval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_GlobalEvalObj.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_GlobalEvalObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HashStats.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_HashStats.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_HideCommand.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_HideCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IncrRefCount.3.gz )
( cd usr/man/man3 ; ln -sf Object.3.gz Tcl_IncrRefCount.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Init.3.gz )
( cd usr/man/man3 ; ln -sf Init.3.gz Tcl_Init.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InitCustomHashTable.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_InitCustomHashTable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InitHashTable.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_InitHashTable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InitMemory.3.gz )
( cd usr/man/man3 ; ln -sf DumpActiveMemory.3.gz Tcl_InitMemory.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InitNotifier.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_InitNotifier.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InitObjHashTable.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_InitObjHashTable.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InitStubs.3.gz )
( cd usr/man/man3 ; ln -sf InitStubs.3.gz Tcl_InitStubs.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InputBlocked.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_InputBlocked.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InputBuffered.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_InputBuffered.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Interp.3.gz )
( cd usr/man/man3 ; ln -sf Interp.3.gz Tcl_Interp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InterpDeleted.3.gz )
( cd usr/man/man3 ; ln -sf CrtInterp.3.gz Tcl_InterpDeleted.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_InvalidateStringRep.3.gz )
( cd usr/man/man3 ; ln -sf Object.3.gz Tcl_InvalidateStringRep.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IsChannelExisting.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_IsChannelExisting.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IsChannelRegistered.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_IsChannelRegistered.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IsChannelShared.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_IsChannelShared.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IsSafe.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_IsSafe.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IsShared.3.gz )
( cd usr/man/man3 ; ln -sf Object.3.gz Tcl_IsShared.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_IsStandardChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_IsStandardChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_JoinPath.3.gz )
( cd usr/man/man3 ; ln -sf SplitPath.3.gz Tcl_JoinPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_JoinThread.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_JoinThread.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_LinkVar.3.gz )
( cd usr/man/man3 ; ln -sf LinkVar.3.gz Tcl_LinkVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ListMathFuncs.3.gz )
( cd usr/man/man3 ; ln -sf CrtMathFnc.3.gz Tcl_ListMathFuncs.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ListObjAppendElement.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_ListObjAppendElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ListObjAppendList.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_ListObjAppendList.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ListObjGetElements.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_ListObjGetElements.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ListObjIndex.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_ListObjIndex.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ListObjLength.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_ListObjLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ListObjReplace.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_ListObjReplace.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_LogCommandInfo.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_LogCommandInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MacConvertTextResource.3.gz )
( cd usr/man/man3 ; ln -sf Macintosh.3.gz Tcl_MacConvertTextResource.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MacEvalResource.3.gz )
( cd usr/man/man3 ; ln -sf Macintosh.3.gz Tcl_MacEvalResource.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MacFindResource.3.gz )
( cd usr/man/man3 ; ln -sf Macintosh.3.gz Tcl_MacFindResource.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MacSetEventProc.3.gz )
( cd usr/man/man3 ; ln -sf Macintosh.3.gz Tcl_MacSetEventProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MakeFileChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_MakeFileChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MakeSafe.3.gz )
( cd usr/man/man3 ; ln -sf CrtSlave.3.gz Tcl_MakeSafe.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MakeTcpClientChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenTcp.3.gz Tcl_MakeTcpClientChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Merge.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_Merge.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MutexFinalize.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_MutexFinalize.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MutexLock.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_MutexLock.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_MutexUnlock.3.gz )
( cd usr/man/man3 ; ln -sf Thread.3.gz Tcl_MutexUnlock.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewBooleanObj.3.gz )
( cd usr/man/man3 ; ln -sf BoolObj.3.gz Tcl_NewBooleanObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewByteArrayObj.3.gz )
( cd usr/man/man3 ; ln -sf ByteArrObj.3.gz Tcl_NewByteArrayObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewDoubleObj.3.gz )
( cd usr/man/man3 ; ln -sf DoubleObj.3.gz Tcl_NewDoubleObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewIntObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_NewIntObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewListObj.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_NewListObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewLongObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_NewLongObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewOSTypeObj.3.gz )
( cd usr/man/man3 ; ln -sf Macintosh.3.gz Tcl_NewOSTypeObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewObj.3.gz )
( cd usr/man/man3 ; ln -sf Object.3.gz Tcl_NewObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewStringObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_NewStringObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewUnicodeObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_NewUnicodeObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NewWideIntObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_NewWideIntObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NextHashEntry.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_NextHashEntry.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NotifyChannel.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_NotifyChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_NumUtfChars.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_NumUtfChars.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ObjGetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_ObjGetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ObjSetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_ObjSetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenCommandChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_OpenCommandChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenFileChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_OpenFileChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenTcpClient.3.gz )
( cd usr/man/man3 ; ln -sf OpenTcp.3.gz Tcl_OpenTcpClient.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OpenTcpServer.3.gz )
( cd usr/man/man3 ; ln -sf OpenTcp.3.gz Tcl_OpenTcpServer.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_OutputBuffered.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_OutputBuffered.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Panic.3.gz )
( cd usr/man/man3 ; ln -sf Panic.3.gz Tcl_Panic.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PanicVA.3.gz )
( cd usr/man/man3 ; ln -sf Panic.3.gz Tcl_PanicVA.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ParseBraces.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_ParseBraces.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ParseCommand.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_ParseCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ParseExpr.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_ParseExpr.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ParseQuotedString.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_ParseQuotedString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ParseVar.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_ParseVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ParseVarName.3.gz )
( cd usr/man/man3 ; ln -sf ParseCmd.3.gz Tcl_ParseVarName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgPresent.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgPresent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgPresentEx.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgPresentEx.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgProvide.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgProvide.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgProvideEx.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgProvideEx.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgRequire.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgRequire.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PkgRequireEx.3.gz )
( cd usr/man/man3 ; ln -sf PkgRequire.3.gz Tcl_PkgRequireEx.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PosixError.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_PosixError.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Preserve.3.gz )
( cd usr/man/man3 ; ln -sf Preserve.3.gz Tcl_Preserve.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PrintDouble.3.gz )
( cd usr/man/man3 ; ln -sf PrintDbl.3.gz Tcl_PrintDouble.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_PutEnv.3.gz )
( cd usr/man/man3 ; ln -sf Environment.3.gz Tcl_PutEnv.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_QueueEvent.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_QueueEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Read.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Read.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ReadChars.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_ReadChars.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ReadRaw.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_ReadRaw.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Realloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz Tcl_Realloc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ReapDetachedProcs.3.gz )
( cd usr/man/man3 ; ln -sf DetachPids.3.gz Tcl_ReapDetachedProcs.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RecordAndEval.3.gz )
( cd usr/man/man3 ; ln -sf RecordEval.3.gz Tcl_RecordAndEval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RecordAndEvalObj.3.gz )
( cd usr/man/man3 ; ln -sf RecEvalObj.3.gz Tcl_RecordAndEvalObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpCompile.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpCompile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpExec.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpExec.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpExecObj.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpExecObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpGetInfo.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpGetInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpMatch.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpMatch.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpMatchObj.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpMatchObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegExpRange.3.gz )
( cd usr/man/man3 ; ln -sf RegExp.3.gz Tcl_RegExpRange.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegisterChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_RegisterChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RegisterObjType.3.gz )
( cd usr/man/man3 ; ln -sf ObjectType.3.gz Tcl_RegisterObjType.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Release.3.gz )
( cd usr/man/man3 ; ln -sf Preserve.3.gz Tcl_Release.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ResetResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_ResetResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_RestoreResult.3.gz )
( cd usr/man/man3 ; ln -sf SaveResult.3.gz Tcl_RestoreResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SaveResult.3.gz )
( cd usr/man/man3 ; ln -sf SaveResult.3.gz Tcl_SaveResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ScanCountedElement.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_ScanCountedElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ScanElement.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_ScanElement.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Seek.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Seek.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ServiceAll.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_ServiceAll.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ServiceEvent.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_ServiceEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetAssocData.3.gz )
( cd usr/man/man3 ; ln -sf AssocData.3.gz Tcl_SetAssocData.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetBooleanObj.3.gz )
( cd usr/man/man3 ; ln -sf BoolObj.3.gz Tcl_SetBooleanObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetByteArrayLength.3.gz )
( cd usr/man/man3 ; ln -sf ByteArrObj.3.gz Tcl_SetByteArrayLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetByteArrayObj.3.gz )
( cd usr/man/man3 ; ln -sf ByteArrObj.3.gz Tcl_SetByteArrayObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetChannelBufferSize.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_SetChannelBufferSize.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetChannelOption.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_SetChannelOption.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetCommandInfo.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_SetCommandInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetCommandInfoFromToken.3.gz )
( cd usr/man/man3 ; ln -sf CrtObjCmd.3.gz Tcl_SetCommandInfoFromToken.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetDefaultEncodingDir.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_SetDefaultEncodingDir.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetDoubleObj.3.gz )
( cd usr/man/man3 ; ln -sf DoubleObj.3.gz Tcl_SetDoubleObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetErrno.3.gz )
( cd usr/man/man3 ; ln -sf SetErrno.3.gz Tcl_SetErrno.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetErrorCode.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_SetErrorCode.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetErrorCodeVA.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_SetErrorCodeVA.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetHashValue.3.gz )
( cd usr/man/man3 ; ln -sf Hash.3.gz Tcl_SetHashValue.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetIntObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_SetIntObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetListObj.3.gz )
( cd usr/man/man3 ; ln -sf ListObj.3.gz Tcl_SetListObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetLongObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_SetLongObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetMainLoop.3.gz )
( cd usr/man/man3 ; ln -sf Tcl_Main.3.gz Tcl_SetMainLoop.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetMaxBlockTime.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_SetMaxBlockTime.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetOSTypeObj.3.gz )
( cd usr/man/man3 ; ln -sf Macintosh.3.gz Tcl_SetOSTypeObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetObjErrorCode.3.gz )
( cd usr/man/man3 ; ln -sf AddErrInfo.3.gz Tcl_SetObjErrorCode.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetObjLength.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_SetObjLength.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetObjResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_SetObjResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetPanicProc.3.gz )
( cd usr/man/man3 ; ln -sf Panic.3.gz Tcl_SetPanicProc.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetRecursionLimit.3.gz )
( cd usr/man/man3 ; ln -sf SetRecLmt.3.gz Tcl_SetRecursionLimit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetResult.3.gz )
( cd usr/man/man3 ; ln -sf SetResult.3.gz Tcl_SetResult.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetServiceMode.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_SetServiceMode.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetStdChannel.3.gz )
( cd usr/man/man3 ; ln -sf GetStdChan.3.gz Tcl_SetStdChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetStringObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_SetStringObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetSystemEncoding.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_SetSystemEncoding.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetTimer.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_SetTimer.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetUnicodeObj.3.gz )
( cd usr/man/man3 ; ln -sf StringObj.3.gz Tcl_SetUnicodeObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetVar.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_SetVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_SetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetVar2Ex.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_SetVar2Ex.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SetWideIntObj.3.gz )
( cd usr/man/man3 ; ln -sf IntObj.3.gz Tcl_SetWideIntObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SignalId.3.gz )
( cd usr/man/man3 ; ln -sf Signal.3.gz Tcl_SignalId.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SignalMsg.3.gz )
( cd usr/man/man3 ; ln -sf Signal.3.gz Tcl_SignalMsg.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Sleep.3.gz )
( cd usr/man/man3 ; ln -sf Sleep.3.gz Tcl_Sleep.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SourceRCFile.3.gz )
( cd usr/man/man3 ; ln -sf SourceRCFile.3.gz Tcl_SourceRCFile.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SpliceChannel.3.gz )
( cd usr/man/man3 ; ln -sf CrtChannel.3.gz Tcl_SpliceChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SplitList.3.gz )
( cd usr/man/man3 ; ln -sf SplitList.3.gz Tcl_SplitList.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SplitPath.3.gz )
( cd usr/man/man3 ; ln -sf SplitPath.3.gz Tcl_SplitPath.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_StackChannel.3.gz )
( cd usr/man/man3 ; ln -sf ChnlStack.3.gz Tcl_StackChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_StandardChannels.3.gz )
( cd usr/man/man3 ; ln -sf StdChannels.3.gz Tcl_StandardChannels.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Stat.3.gz )
( cd usr/man/man3 ; ln -sf Access.3.gz Tcl_Stat.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_StaticPackage.3.gz )
( cd usr/man/man3 ; ln -sf StaticPkg.3.gz Tcl_StaticPackage.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_StringCaseMatch.3.gz )
( cd usr/man/man3 ; ln -sf StrMatch.3.gz Tcl_StringCaseMatch.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_StringMatch.3.gz )
( cd usr/man/man3 ; ln -sf StrMatch.3.gz Tcl_StringMatch.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_SubstObj.3.gz )
( cd usr/man/man3 ; ln -sf SubstObj.3.gz Tcl_SubstObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Tell.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Tell.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ThreadAlert.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_ThreadAlert.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ThreadQueueEvent.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_ThreadQueueEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_TraceCommand.3.gz )
( cd usr/man/man3 ; ln -sf TraceCmd.3.gz Tcl_TraceCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_TraceVar.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_TraceVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_TraceVar2.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_TraceVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_TranslateFileName.3.gz )
( cd usr/man/man3 ; ln -sf Translate.3.gz Tcl_TranslateFileName.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Ungets.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Ungets.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniChar.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniChar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharAtIndex.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniCharAtIndex.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharCaseMatch.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniCharCaseMatch.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsAlnum.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsAlnum.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsAlpha.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsAlpha.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsControl.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsControl.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsDigit.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsDigit.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsGraph.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsGraph.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsLower.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsLower.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsPrint.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsPrint.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsPunct.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsPunct.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsSpace.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsSpace.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsUpper.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsUpper.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharIsWordChar.3.gz )
( cd usr/man/man3 ; ln -sf UniCharIsAlpha.3.gz Tcl_UniCharIsWordChar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharLen.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniCharLen.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharNcasecmp.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniCharNcasecmp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharNcmp.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniCharNcmp.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharToLower.3.gz )
( cd usr/man/man3 ; ln -sf ToUpper.3.gz Tcl_UniCharToLower.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharToTitle.3.gz )
( cd usr/man/man3 ; ln -sf ToUpper.3.gz Tcl_UniCharToTitle.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharToUpper.3.gz )
( cd usr/man/man3 ; ln -sf ToUpper.3.gz Tcl_UniCharToUpper.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharToUtf.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniCharToUtf.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UniCharToUtfDString.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UniCharToUtfDString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnlinkVar.3.gz )
( cd usr/man/man3 ; ln -sf LinkVar.3.gz Tcl_UnlinkVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnregisterChannel.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_UnregisterChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnsetVar.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_UnsetVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnsetVar2.3.gz )
( cd usr/man/man3 ; ln -sf SetVar.3.gz Tcl_UnsetVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UnstackChannel.3.gz )
( cd usr/man/man3 ; ln -sf ChnlStack.3.gz Tcl_UnstackChannel.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UntraceCommand.3.gz )
( cd usr/man/man3 ; ln -sf TraceCmd.3.gz Tcl_UntraceCommand.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UntraceVar.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_UntraceVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UntraceVar2.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_UntraceVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UpVar.3.gz )
( cd usr/man/man3 ; ln -sf UpVar.3.gz Tcl_UpVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UpVar2.3.gz )
( cd usr/man/man3 ; ln -sf UpVar.3.gz Tcl_UpVar2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UpdateLinkedVar.3.gz )
( cd usr/man/man3 ; ln -sf LinkVar.3.gz Tcl_UpdateLinkedVar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfAtIndex.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfAtIndex.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfBackslash.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfBackslash.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfCharComplete.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfCharComplete.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfFindFirst.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfFindFirst.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfFindLast.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfFindLast.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfNext.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfNext.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfPrev.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfPrev.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfToExternal.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_UtfToExternal.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfToExternalDString.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_UtfToExternalDString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfToLower.3.gz )
( cd usr/man/man3 ; ln -sf ToUpper.3.gz Tcl_UtfToLower.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfToTitle.3.gz )
( cd usr/man/man3 ; ln -sf ToUpper.3.gz Tcl_UtfToTitle.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfToUniChar.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfToUniChar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfToUniCharDString.3.gz )
( cd usr/man/man3 ; ln -sf Utf.3.gz Tcl_UtfToUniCharDString.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_UtfToUpper.3.gz )
( cd usr/man/man3 ; ln -sf ToUpper.3.gz Tcl_UtfToUpper.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_ValidateAllMemory.3.gz )
( cd usr/man/man3 ; ln -sf DumpActiveMemory.3.gz Tcl_ValidateAllMemory.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_VarEval.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_VarEval.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_VarEvalVA.3.gz )
( cd usr/man/man3 ; ln -sf Eval.3.gz Tcl_VarEvalVA.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_VarTraceInfo.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_VarTraceInfo.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_VarTraceInfo2.3.gz )
( cd usr/man/man3 ; ln -sf TraceVar.3.gz Tcl_VarTraceInfo2.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WaitForEvent.3.gz )
( cd usr/man/man3 ; ln -sf Notifier.3.gz Tcl_WaitForEvent.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WaitPid.3.gz )
( cd usr/man/man3 ; ln -sf DetachPids.3.gz Tcl_WaitPid.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WinTCharToUtf.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_WinTCharToUtf.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WinUtfToTChar.3.gz )
( cd usr/man/man3 ; ln -sf Encoding.3.gz Tcl_WinUtfToTChar.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_Write.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_Write.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WriteChars.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_WriteChars.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WriteObj.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_WriteObj.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WriteRaw.3.gz )
( cd usr/man/man3 ; ln -sf OpenFileChnl.3.gz Tcl_WriteRaw.3.gz )
( cd usr/man/man3 ; rm -rf Tcl_WrongNumArgs.3.gz )
( cd usr/man/man3 ; ln -sf WrongNumArgs.3.gz Tcl_WrongNumArgs.3.gz )
( cd usr/man/man3 ; rm -rf attemptckalloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz attemptckalloc.3.gz )
( cd usr/man/man3 ; rm -rf attemptckrealloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz attemptckrealloc.3.gz )
( cd usr/man/man3 ; rm -rf ckalloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz ckalloc.3.gz )
( cd usr/man/man3 ; rm -rf ckfree.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz ckfree.3.gz )
( cd usr/man/man3 ; rm -rf ckrealloc.3.gz )
( cd usr/man/man3 ; ln -sf Alloc.3.gz ckrealloc.3.gz )
( cd usr/man/man3 ; rm -rf panic.3.gz )
( cd usr/man/man3 ; ln -sf Panic.3.gz panic.3.gz )
( cd usr/man/man3 ; rm -rf panicVA.3.gz )
( cd usr/man/man3 ; ln -sf Panic.3.gz panicVA.3.gz )
( cd usr/man/mann ; rm -rf SafeBase.n.gz )
( cd usr/man/mann ; ln -sf safe.n.gz SafeBase.n.gz )
( cd usr/man/mann ; rm -rf auto_execok.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz auto_execok.n.gz )
( cd usr/man/mann ; rm -rf auto_import.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz auto_import.n.gz )
( cd usr/man/mann ; rm -rf auto_load.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz auto_load.n.gz )
( cd usr/man/mann ; rm -rf auto_mkindex.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz auto_mkindex.n.gz )
( cd usr/man/mann ; rm -rf auto_mkindex_old.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz auto_mkindex_old.n.gz )
( cd usr/man/mann ; rm -rf auto_qualify.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz auto_qualify.n.gz )
( cd usr/man/mann ; rm -rf auto_reset.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz auto_reset.n.gz )
( cd usr/man/mann ; rm -rf parray.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz parray.n.gz )
( cd usr/man/mann ; rm -rf pkg::create.n.gz )
( cd usr/man/mann ; ln -sf packagens.n.gz pkg::create.n.gz )
( cd usr/man/mann ; rm -rf pkg_mkIndex.n.gz )
( cd usr/man/mann ; ln -sf pkgMkIndex.n.gz pkg_mkIndex.n.gz )
( cd usr/man/mann ; rm -rf tcl_endOfWord.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz tcl_endOfWord.n.gz )
( cd usr/man/mann ; rm -rf tcl_findLibrary.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz tcl_findLibrary.n.gz )
( cd usr/man/mann ; rm -rf tcl_startOfNextWord.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz tcl_startOfNextWord.n.gz )
( cd usr/man/mann ; rm -rf tcl_startOfPreviousWord.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz tcl_startOfPreviousWord.n.gz )
( cd usr/man/mann ; rm -rf tcl_wordBreakAfter.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz tcl_wordBreakAfter.n.gz )
( cd usr/man/mann ; rm -rf tcl_wordBreakBefore.n.gz )
( cd usr/man/mann ; ln -sf library.n.gz tcl_wordBreakBefore.n.gz )
